@@ -11,6 +11,26 @@ def sql(key):
             'sql':"SELECT `groupId` FROM loggroup where groupName LIKE '%mysystemmetric%' order  by createTime desc;",
             'database': 'AnyRobot'
         },
+        'CPUSLO': {
+            'sql': "SELECT `id` FROM kai_service where name LIKE '%Linux主机CPU服务SLO%' order  by create_time desc;",
+            'database': 'AnyRobot'
+        },
+        'MemorySLO': {
+            'sql': "SELECT `id` FROM kai_service where name LIKE '%Linux主机内存服务SLO%' order  by create_time desc;",
+            'database': 'AnyRobot'
+        },
+        'LoadSLO': {
+            'sql': "SELECT `id` FROM kai_service where name LIKE '%Linux主机平均负载服务SLO%' order  by create_time desc;",
+            'database': 'AnyRobot'
+        },
+        'IOSLO': {
+            'sql': "SELECT `id` FROM kai_service where name LIKE '%Linux主机IO利用率服务SLO%' order  by create_time desc;",
+            'database': 'AnyRobot'
+        },
+        'DiskSLO': {
+            'sql': "SELECT `id` FROM kai_service where name LIKE '%Linux主机磁盘利用率服务SLO%' order  by create_time desc;",
+            'database': 'AnyRobot'
+        },
         'UserID':{'sql':'select userId from User where loginName = "admin";','database':'AnyRobot'},
         'MLID': {'sql': "select id from MLJob ;", 'database': 'AnyRobotML'},
         'entityID': {'sql': "select id from KAIEntity;", 'database': 'AnyRobot'},
