@@ -1,5 +1,5 @@
 import time
-import random
+import random,datetime
 
 class date(object):
     def getStartTime(self):
@@ -33,3 +33,7 @@ class date(object):
 
     def getDateTime(self):
         return str(time.strftime('%Y-%m-%d %H:%M:%S'))
+
+    def getNowYear(self):
+        return datetime.datetime.now().year
+
